@@ -1,7 +1,9 @@
 import asyncio
 import aiohttp
+import traceback
 
 from .handlers import Handlers
+from .dispatcher import Dispatcher
 
 
 class Handler:
@@ -36,14 +38,17 @@ class Bot:
                         async with session.get("https://%s?act=a_check&key=%s&ts=%s&wait=60&mode=2&version=5.126" % (self.config["server"], self.config["key"], self.config["ts"])) as response:
                             event = await response.json()
                             updates = event["updates"]
-                            print(event)
+                            if len(updates) == 0:
+                                continue
+                            print(updates)
+
                             self.config["ts"] = event["ts"]
 
                             tasks = [asyncio.create_task(handler.new_event(self.token, updates[0]))
                                      for handler in self.handlers if handler.event_type == updates[0]["type"]]
 
                     except:
-                        pass
+                        print(traceback.format_exc())
 
     async def execute(self, method: str, **params) -> dict:
         query = f"https://api.vk.com/method/{method}?"
@@ -58,4 +63,4 @@ class Bot:
 
 def run_polling(bot: Bot) -> None:
     loop = asyncio.get_event_loop()
-    loop.run_until_complete(bot.run_polling())
+    loop.run_until_complete(bot.run_polling())
\ No newline at end of file
