@@ -1,15 +1,16 @@
 import asyncio
 import aiosqlite
+from typing import Iterable, Any
 
 
 class Synchronizer:
     def __init__(self):
         self.is_open = True
 
-    def open(self):
+    def open(self) -> None:
         self.is_open = True
 
-    def close(self):
+    def close(self) -> None:
         self.is_open = False
 
     async def __aenter__(self):
@@ -19,19 +20,19 @@ class Synchronizer:
     async def __aexit__(self, *args, **kwargs):
         self.open()
 
-    async def wait_for_opening(self):
+    async def wait_for_opening(self) -> None:
         while not self.is_open:
             await asyncio.sleep(0.2)
 
 
 class SQLite(Synchronizer):
-    def __init__(self, filename):
+    def __init__(self, filename: str):
         super().__init__()
         self.filename = filename
 
-    async def execute(self, query):
+    async def execute(self, query: str, parameters: Iterable[Any] = None):
         async with aiosqlite.connect(self.filename) as db:
-            async with db.execute(query) as cursor:
+            async with db.execute(query, parameters) as cursor:
                 result = await cursor.fetchall()
                 await db.commit()
                 return result
